testtier

package
v0.26.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 28, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	ExtraEnv   = "BATON_TEST_EXTRA"
	NightlyEnv = "BATON_TEST_NIGHTLY"
)

Variables

This section is empty.

Functions

func RequireExtra

func RequireExtra(t testing.TB)

RequireExtra skips a deterministic long-running test unless an extra or nightly confidence suite explicitly enabled it.

func RequireNightly

func RequireNightly(t testing.TB)

RequireNightly skips a randomized, repeated, or full-corpus test unless the nightly confidence suite explicitly enabled it.

Types

This section is empty.

Jump to