exit

package
v0.25.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 21, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Exit

func Exit(err error)

Exit exits the program with a code based on the error. Exit codes correspond to GRPC status codes. If err is nil, exit code is 0. Common errors such as context cancelled and deadline exceeded exit with the corresponding GRPC status code. Other errors exit with code 2, which is GRPC status code Unknown.

func LogExit

func LogExit(err error)

LogExit logs the error to stderr & calls Exit(), which exits the program with a code based on the error.

Types

This section is empty.

Jump to